<?php

namespace Intuit\Commands;

use GuzzleHttp\Exception\ConnectException;
use Illuminate\Console\Command;
use Intuit\Exceptions\ConnectionIssueException;
use Intuit\Exceptions\NotFoundException;
use Intuit\Traits\ProviderTokenTrait;

class AccountGet extends Command
{
	use ProviderTokenTrait;

	/**
	 * The name and signature of the console command.
	 *
	 * @var string
	 */
	protected $signature = 'intuit:account:get'
		.' {id : Account ID}'
		.' {user? : User Email}';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = 'Get an account from quickbooks';

	/**
	 * Execute the console command.
	 *
	 * @return int
	 */
	public function handle()
	{
		$to = $this->providerToken($this->argument('user'));

		try {
			dump($to->API()->getAccountQuery($this->argument('id')));

		} catch (ConnectException|ConnectionIssueException $e) {
			$this->error($e->getMessage());

			return self::FAILURE;

		} catch (NotFoundException $e) {
			$this->error('Nothing found');

			return self::FAILURE;
		}

		return self::SUCCESS;
	}
}