<?php

namespace Intuit\Commands;

use GuzzleHttp\Exception\ConnectException;
use Illuminate\Console\Command;
use Intuit\Exceptions\ConnectionIssueException;
use Intuit\Exceptions\NotFoundException;
use Intuit\Traits\ProviderTokenTrait;

use App\Jobs\AccountingPaymentSync as Job;

class PaymentGet extends Command
{
	use ProviderTokenTrait;

	/**
	 * The name and signature of the console command.
	 *
	 * @var string
	 */
	protected $signature = 'intuit:payment:get'
		.' {id : Payment ID}'
		.' {user? : User Email}';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = 'Get a payment from the accounting provider';

	/**
	 * Execute the console command.
	 *
	 * @return int
	 */
	public function handle()
	{
		$to = $this->providerToken($this->argument('user'));

		try {
			dd($to->API()->getPayment($this->argument('id')));

		} catch (ConnectException|ConnectionIssueException $e) {
			$this->error($e->getMessage());

			return self::FAILURE;

		} catch (NotFoundException $e) {
			$this->error('Nothing found');

			return self::FAILURE;
		}

		if ($acc)
			Job::dispatchSync($to,$acc);

		return self::SUCCESS;
	}
}