<?php

namespace Intuit\Controllers;

use App\Events\ProviderPaymentCreated;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller as BaseController;
use Illuminate\Support\Facades\Log;
use Intuit\Response\Webhook as Payload;

class Webhook extends BaseController
{
	use DispatchesJobs;

	private const name = 'intuit';

	public function webhook(Request $request)
	{
		$signature = $request->header('Intuit-Signature');
		// Load the secret, you also can load it from env(YOUR_OWN_SLACK_SECRET)
		$secret = config(sprintf('services.provider.%s.verifytoken',self::name));

		Log::channel('webhook')->debug('Payload: '.$request->getContent());
		Log::channel('webhook')->debug('Signature: '.$signature);

		$payloadHash = hash_hmac('sha256',$request->getContent(),$secret);
		$singatureHash = bin2hex(base64_decode($signature));

		if ($payloadHash == $singatureHash) {
			Log::channel('webhook')->debug('Signature OK');
		} else {
			Log::channel('webhook')->alert('Signature NOT ok.');
		}

		$payload = new Payload(json_decode($request->getContent(),TRUE));

		foreach ($payload->types() as $type) {

			switch ($type) {
				case 'eventNotifications':

					foreach ($payload->event($type) as $dataObject) {
						Log::info('Event for realm: '.$dataObject['realmId'],['data'=>$dataObject]);

						foreach ($dataObject['dataChangeEvent'] as $object => $data) {
							switch ($object) {
								case 'entities':
									foreach ($data as $eventData) {
										switch ($x=$eventData['name']) {
											case 'Payment':
												Log::alert(sprintf('We got a payment event [%s:%s]',$object,$x),['data'=>$eventData]);
												event(new ProviderPaymentCreated('intuit',$eventData));
												break;

											default:
												Log::alert(sprintf('We dont know how to handle [%s:%s] yet',$object,$x),['data'=>$eventData]);
										}
									}
									break;

								default:
									Log::error(sprintf('Unknown object: %s in %s',$object,$type),['data'=>$data]);
							}
						}
					}

					break;

				default:
					Log::error('Unknown webhook payload type: '.$type,['data'=>$data]);
			}
		}
	}
}