<?php

namespace Intuit\Response;

use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Log;
use Jenssegers\Model\Model;

/**
 * This parent class handles responses received from Intuit
 *
 * @note: This class is used for events not specifically created.
 */
abstract class Base implements \JsonSerializable
{
	protected const LOGKEY = 'RB-';

	protected Model $_model;

	/**
	 * Default Constructor Setup
	 *
	 * @param object $response
	 * @throws \Exception
	 */
	public function __construct(object $response)
	{
		// This is only for child classes
		if (get_class($this) == Base::class) {
			Log::debug(sprintf('%s:Intuit RESPONSE Initialised [%s]',static::LOGKEY,get_class($this)),['m'=>__METHOD__]);

			if (App::environment() == 'dev')
				file_put_contents('/tmp/response',print_r($this,TRUE),FILE_APPEND);
		}
	}

	public function __get($key) {
		return $this->_model->__get($key);
	}

	/* ABSTRACT */

	/**
	 * When we json_encode this object, this is the data that will be returned
	 */
	public function jsonSerialize(): mixed
	{
		return $this->_data ?: new \stdClass;
	}

	/**
	 * Search for an item in the result
	 *
	 * @param string $key
	 * @param mixed $value
	 * @return mixed
	 */
	public function search(string $key,mixed $value): mixed
	{
		return $this->_data->search(fn($item)=>$item->{$key}===$value);
	}
}